/*******************************************************************************
 * ============LICENSE_START========================================================================
 * ONAP : ccsdk feature sdnr wt
 * =================================================================================================
 * Copyright (C) 2019 highstreet technologies GmbH Intellectual Property. All rights reserved.
 * =================================================================================================
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 * ============LICENSE_END==========================================================================
 ******************************************************************************/

package org.onap.ccsdk.features.sdnr.wt.mountpointregistrar.impl;

import java.io.IOException;
import java.util.Base64;
import java.util.HashMap;
import java.util.Map;

import org.onap.ccsdk.features.sdnr.wt.common.http.BaseHTTPClient;
import org.onap.ccsdk.features.sdnr.wt.common.http.BaseHTTPResponse;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

public class PNFMountPointClient extends BaseHTTPClient {

	private static final Logger LOG = LoggerFactory.getLogger(PNFMountPointClient.class);
	private static final String MOUNTPOINT_URI = "restconf/config/network-topology:network-topology/topology/topology-netconf/node/";
	private final Map<String, String> headerMap;
	private static final String SSH_PAYLOAD = "<node xmlns=\"urn:TBD:params:xml:ns:yang:network-topology\">\n" +
			"  <node-id>@device-name@</node-id>\n" +
			"  <host xmlns=\"urn:opendaylight:netconf-node-topology\">@device-ip@</host>\n" +
			"  <port xmlns=\"urn:opendaylight:netconf-node-topology\">@device-port@</port>\n" +
			"  <username xmlns=\"urn:opendaylight:netconf-node-topology\">@username@</username>\n" +
			"  <password xmlns=\"urn:opendaylight:netconf-node-topology\">@password@</password>\n" +
			"  <tcp-only xmlns=\"urn:opendaylight:netconf-node-topology\">false</tcp-only>\n" +
			"  <!-- non-mandatory fields with default values, you can safely remove these if you do not wish to override any of these values-->\n" +
			"  <reconnect-on-changed-schema xmlns=\"urn:opendaylight:netconf-node-topology\">false</reconnect-on-changed-schema>\n" +
			"  <connection-timeout-millis xmlns=\"urn:opendaylight:netconf-node-topology\">20000</connection-timeout-millis>\n" +
			"  <max-connection-attempts xmlns=\"urn:opendaylight:netconf-node-topology\">0</max-connection-attempts>\n" +
			"  <between-attempts-timeout-millis xmlns=\"urn:opendaylight:netconf-node-topology\">2000</between-attempts-timeout-millis>\n" +
			"  <sleep-factor xmlns=\"urn:opendaylight:netconf-node-topology\">1.5</sleep-factor>\n" +
			"  <!-- keepalive-delay set to 0 turns off keepalives-->\n" +
			"  <keepalive-delay xmlns=\"urn:opendaylight:netconf-node-topology\">120</keepalive-delay>\n" +
			"</node>";
	private static final String TLS_PAYLOAD = "<node xmlns=\"urn:TBD:params:xml:ns:yang:network-topology\">\n" +
			"  <node-id>@device-name@</node-id>\n" +
			"  <host xmlns=\"urn:opendaylight:netconf-node-topology\">@device-ip@</host>\n" +
			"  <port xmlns=\"urn:opendaylight:netconf-node-topology\">@device-port@</port>\n" +
			"  <key-based xmlns=\"urn:opendaylight:netconf-node-topology\">\n" +
			"	  <username xmlns=\"urn:opendaylight:netconf-node-topology\">@username@</username>\n" +
 			"	  <key-id>@key-id@</key-id>\n" +
			"  </key-based>\n" +
			"  <tcp-only xmlns=\"urn:opendaylight:netconf-node-topology\">false</tcp-only>\n" +
			"  <protocol xmlns=\"urn:opendaylight:netconf-node-topology\">\n" +
			"	<name>TLS</name>\n" +
			"  </protocol>\n" +
			"	<!-- non-mandatory fields with default values, you can safely remove these if you do not wish to override any of these values-->\n" +
			"	<reconnect-on-changed-schema xmlns=\"urn:opendaylight:netconf-node-topology\">false</reconnect-on-changed-schema>\n" +
			"	<connection-timeout-millis xmlns=\"urn:opendaylight:netconf-node-topology\">20000</connection-timeout-millis>\n" +
			"	<max-connection-attempts xmlns=\"urn:opendaylight:netconf-node-topology\">0</max-connection-attempts>\n" +
			"	<between-attempts-timeout-millis xmlns=\"urn:opendaylight:netconf-node-topology\">2000</between-attempts-timeout-millis>\n" +
			"	<sleep-factor xmlns=\"urn:opendaylight:netconf-node-topology\">1.5</sleep-factor>\n" +
			"	<!-- keepalive-delay set to 0 turns off keepalives-->\n" +
			"	<keepalive-delay xmlns=\"urn:opendaylight:netconf-node-topology\">120</keepalive-delay>\n" +
			"</node>";

	public PNFMountPointClient(String baseUrl) {
		super(baseUrl);

		this.headerMap = new HashMap<>();
        this.headerMap.put("Content-Type", "application/xml");
        this.headerMap.put("Accept", "application/xml");
	}

	public void setAuthorization(String username, String password) {
		String credentials = username + ":" + password;
		this.headerMap.put("Authorization",
				"Basic " + new String(Base64.getEncoder().encode(credentials.getBytes())));

	}

	public boolean pnfMountPointCreate(String pnfName, String ipv4Address, String protocol, String keyId, String username, String password, String commPort) {
		String message = "";
		if (protocol.equals("TLS")) {
			message = updateTLSPayload(pnfName, ipv4Address, username, keyId, commPort);
		} else { //SSH
			message = updatePayload(pnfName, ipv4Address, username, password, commPort);
			LOG.debug("Payload after updating values is: {}",message);
		}
		return pnfRequest(pnfName, "PUT", message) == 200;

	}

	private static String updatePayload(String pnfName, String ipv4Address, String username, String password, String portNo) {
		return SSH_PAYLOAD.replace("@device-name@", pnfName)
							.replace("@device-ip@", ipv4Address)
							.replace("@device-port@", portNo)
							.replace("@username@",  username)
							.replace("@password@",  password);
	}

	private static String updateTLSPayload(String pnfName, String ipv4Address, String username, String keyId, String portNo) {
		return TLS_PAYLOAD.replace("@device-name@", pnfName)
							.replace("@device-ip@", ipv4Address)
							.replace("@username@", username)
							.replace("@key-id@", keyId)
							.replace("@device-port@", portNo);
	}

	 private int pnfRequest(String pnfName, String method, String message) {
		 LOG.info("In pnfRequest - {} : {} : {}",pnfName,method,message);
	        BaseHTTPResponse response;
	        try {
	            //String uri = "http://localhost:8181/restconf/config/network-topology:network-topology/topology/topology-netconf/node/" + pnfName;
	            String uri = MOUNTPOINT_URI + pnfName;
	            response = this.sendRequest(uri, method, message, headerMap);
	            LOG.debug("finished with responsecode {}", response.code);
	            return response.code;
	        } catch (IOException e) {
	            LOG.warn("problem registering {} : {}", pnfName, e.getMessage());
	            return -1;
	        }
	    }

}
